#
# spec file for package xfce4-calculator-plugin
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.12.0
%define plugin calculator
%bcond_with git
Name:           xfce4-%{plugin}-plugin
Version:        0.7.2
Release:        1.5
Summary:        Calculator plugin for the Xfce4 panel
License:        GPL-2.0-only
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-calculator-plugin
Source:         https://archive.xfce.org/src/panel-plugins/%{name}/0.7/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4util-1.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfconf-0) >= %{panel_version}
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
xfce4-calculator-plugin is a calculator plugin for the Xfce4 panel.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
  --enable-maintainer-mode \
  --disable-static
%else
%configure --disable-static
%endif
%make_build

%install
%make_install

%find_lang %{name} %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc AUTHORS NEWS README.md
%{_libdir}/xfce4/panel/plugins/libcalculator.la
%{_libdir}/xfce4/panel/plugins/libcalculator.so
%{_datadir}/icons/hicolor/*
%{_datadir}/xfce4/panel/plugins/calculator.desktop

%files lang -f %{name}.lang

%changelog
* Thu Apr 20 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to 0.7.2
  * Add basic GitLab pipeline
  * Use same automake options as other projects
  * build: Fix intltool lock file problem during make distcheck
  * Update copyright year
  * Remove deprecated project files
  * build: Add missing includes
  * build: Fix autoconf warnings
  * build: Add GLib requirement
  * Use "logo-icon-name" instead of "logo" in about dialog
  * Fix license notices mentioning LGPL (#7)
  * tests: Parenthesize concatenations to avoid ambiguity
  * Fix the 64x64 icon
  * Fix compilation warnings
  * autoconf: Some updates
  * Update bug report URL
  * Make configure.ac.in more friendly to xfce-do-release helper
  * Translation Updates
- Remove _service file
* Wed Dec 23 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 0.7.1
  * Add option to not move cursor after calculations (#3)
  * Align spin buttons in properties dialog
  * Add close button to properties dialog
  * Handle delete event when properties dialog is closed
  * Adds new README.md updates AM_INIT_AUTOMAKE
  * Update URLs from goodies.x.o to docs.x.o (bxo#16155)
  * Allow compilation with panel 4.15
  * Disable emoji input
  * Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Tue Jul 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
* Mon Feb 25 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to 0.7.0
  * GTK3 Port and features from the 0.6.90 release
  * Added Translations
* Tue Jan 15 2019 Maurizio Galli <maurizio.galli@gmail.com>
- initial build
